# simple_requests

[![Build Status](https://travis-ci.org/martinsik/dart-simple-requests.svg?branch=master)](https://travis-ci.org/martinsik/dart-simple-requests)

Dart wrapper around server-side `HttpClientRequest` for easy creating HTTP requests.

## Installation

```
dependencies:
  simple_requests: "^0.1.0"
```

Then run `pub get`.

## Usage

#### 1. Most simple use case with GET request:

```dart
import 'package:simple_requests/simple_requests.dart';

var response = await request(Uri.parse('http://httpbin.org/get'));

print("statusCode: ${response.statusCode}");
print("content: ${response.content}");
print("response headers: ${response.headers}");
```

#### 2. Creating POST requests

```dart
var postData = 'Hello, World!';
var uri = Uri.parse('http://httpbin.org/post');
var response = await request(uri, method: HTTPMethod.POST, payload: postData);
```

#### 3. Creating JSON requests

Method `requestJson` automatically encodes all requests and responses to and from JSON.

```dart
var requestData = {
  'post_key_1': 'value1',
  'post_key_2': 'value2',
};
var uri = Uri.parse('http://httpbin.org/get');

Map<String, dynamic> resp = await requestJson(uri, payload: requestData);
// Decoded response. Url `http://httpbin.org/get` returns a JSON
// with all request parameters, headers and so on.
```

## Test

Run tests with:

```
pub run test
```

## License

simple_requests is licensed under The MIT License.