library simple_requests;

import 'dart:async';
import 'dart:io';
import 'dart:convert';
import 'dart:core';


Future<SimpleHTTPResponse> request(Uri uri, {Map<String, String> headers, method: HTTPMethod.GET, payload: null}) async {
  Completer completer = new Completer();

  HttpClient client = new HttpClient();

  var req;
  if (method == HTTPMethod.POST) {
    req = client.postUrl(uri);
  } else if (method == HTTPMethod.DELETE) {
    req = client.deleteUrl(uri);
  } else if (method == HTTPMethod.PUT) {
    req = client.putUrl(uri);
  } else {
    req = client.getUrl(uri);
  }
  HttpClientRequest obj = await req;

  if (headers != null) {
    headers.forEach((name, value) => obj.headers.add(name, value));
  }

  var body = '';
  if (payload is Map) {
    body = payload.keys.map((key) => "${Uri.encodeComponent(key)}=${Uri.encodeComponent(payload[key])}").join("&");
    obj.headers.set('content-type', 'application/x-www-form-urlencoded');
  } else if (payload != null) {
    body = payload.toString();
  }
  obj.contentLength = body.length;
  obj.write(body);

  // Send the request.
  var response = await obj.close();

  // Use StringBuffer for effective concatenating strings.
  StringBuffer contents = new StringBuffer();
  response.transform(UTF8.decoder).listen((String data) {
    contents.write(data);
  }, onDone: () {
    // Wrap response.
    var resp = new SimpleHTTPResponse(contents.toString(), response.statusCode, response.headers, obj.headers, body);
    completer.complete(resp);
  });

  return completer.future;
}

Future<SimpleHTTPResponse> requestJson(Uri uri, {Map<String, String> headers, method: HTTPMethod.GET, payload: null}) async {
  SimpleHTTPResponse response = await request(uri, headers: headers, method: method, payload: JSON.encode(payload));
  return new SimpleHTTPResponse(JSON.decode(response.content), response.statusCode, response.headers, response.requestHeaders, JSON.decode(response.requestContent));
}

class SimpleHTTPResponse {
  final dynamic content;
  final dynamic requestContent;
  final int statusCode;
  final HttpHeaders headers;
  final HttpHeaders requestHeaders;

  SimpleHTTPResponse(this.content, this.statusCode, this.headers, this.requestHeaders, this.requestContent);
}

enum HTTPMethod {
  GET,
  POST,
  DELETE,
  PUT,
}