library simple_requests.test;

import 'dart:convert';
import 'package:test/test.dart';
import 'package:simple_requests/simple_requests.dart';


void main() {
  // http://httpbin.org/

  test('Simple HTTP GET request', () async {
    var response = await request(Uri.parse('http://httpbin.org/get'));
    expect(response.statusCode, equals(200));
  });

  test('Simple HTTP GET with arguments', () async {
    var uri = new Uri.http('httpbin.org', '/get', {'param1': 'value1', 'param2': 'value2'});
    var response = await requestJson(uri);
    expect(response.statusCode, equals(200));
    var json = response.content;
    expect(json['args'], containsPair('param1', 'value1'));
    expect(json['args'], containsPair('param2', 'value2'));
  });

  test('Test POST with headers', () async {
    var uri = new Uri.http('httpbin.org', '/post');
    var response = await requestJson(uri, method: HTTPMethod.POST, headers: {'Etag': 'My-Value'});
    expect(response.statusCode, equals(200));
    expect(response.content['headers'], containsPair('Etag', 'My-Value'));
  });

  test('Test POST with payload', () async {
    var uri = new Uri.http('httpbin.org', '/post');
    var requestData = {
      'post_key_1': 'value1',
      'post_key_2': 'value2',
    };

    // Simple string payload.
    var response1 = await request(uri, method: HTTPMethod.POST, payload: requestData);
    expect(response1.statusCode, equals(200));
    expect(JSON.decode(response1.content)['form'], equals(requestData));

    // JSON payload.
    var response2 = await requestJson(uri, method: HTTPMethod.POST, payload: requestData);
    expect(response2.statusCode, equals(200));
    expect(response2.content['data'], equals('{"post_key_1":"value1","post_key_2":"value2"}'));
    expect(response2.requestContent, containsPair('post_key_2', 'value2'));
  });

}